@@ -16,7 +16,7 @@ extern crate pyo3;
 
 extern crate tempfile;
 
-extern crate clvm_rust as clvm_rs;
+extern crate clvmr as clvm_rs;
 
 mod util;
 
