@@ -126,6 +126,13 @@ fn run_test_1_maybe_opt(opt: bool) {
     assert_eq!(result.to_string(), "10".to_string());
 }
 
+#[test]
+fn compile_test_7() {
+    let result =
+        compile_string(&"(mod (X) (include *standard-cl-21*) (/ X 10))".to_string()).unwrap();
+    assert_eq!(result, "(2 (1 5 (20 5 (1 . 10))) (4 (1) 1))".to_string());
+}
+
 #[test]
 fn run_test_1() {
     run_test_1_maybe_opt(false);
